@@ -13,25 +13,16 @@
 
 """Utility for fetching a resource (e.g. a manifest) from a URL."""
 
-from oslo_config import cfg
 from oslo_log import log as logging
 import requests
 from requests import exceptions
 from six.moves import urllib
 
 from magnum.common import exception
+import magnum.conf
 from magnum.i18n import _
-from magnum.i18n import _LE
-from magnum.i18n import _LI
-
-URLFETCH_OPTS = [
-    cfg.IntOpt('max_manifest_size',
-               default=524288,
-               help=_('Maximum raw byte size of any manifest.'))
-]
-
-cfg.CONF.register_opts(URLFETCH_OPTS)
 
+CONF = magnum.conf.CONF
 LOG = logging.getLogger(__name__)
 
 
@@ -43,25 +34,17 @@ def get(url, allowed_schemes=('http', 'https')):
     """Get the data at the specified URL.
 
     The URL must use the http: or https: schemes.
-    The file: scheme is also supported if you override
-    the allowed_schemes argument.
     Raise an IOError if getting the data fails.
     """
-    LOG.info(_LI('Fetching data from %s'), url)
+    LOG.info('Fetching data from %s', url)
 
     components = urllib.parse.urlparse(url)
 
     if components.scheme not in allowed_schemes:
         raise URLFetchError(_('Invalid URL scheme %s') % components.scheme)
 
-    if components.scheme == 'file':  # nosec
-        try:
-            return urllib.request.urlopen(url).read()
-        except urllib.error.URLError as uex:
-            raise URLFetchError(_('Failed to retrieve manifest: %s') % uex)
-
     try:
-        resp = requests.get(url, stream=True)
+        resp = requests.get(url, stream=True, timeout=60)
         resp.raise_for_status()
 
         # We cannot use resp.text here because it would download the
@@ -76,10 +59,10 @@ def get(url, allowed_schemes=('http', 'https')):
         result = ""
         for chunk in reader:
             result += chunk
-            if len(result) > cfg.CONF.max_manifest_size:
-                raise URLFetchError(_LE("Manifest exceeds maximum allowed"
-                                        "size (%s bytes)") %
-                                    cfg.CONF.max_manifest_size)
+            if len(result) > CONF.max_manifest_size:
+                raise URLFetchError("Manifest exceeds maximum allowed "
+                                    "size (%s bytes)" %
+                                    CONF.max_manifest_size)
         return result
 
     except exceptions.RequestException as ex:
