@@ -25,10 +25,15 @@ Create Date: 2015-09-03 20:51:54.229436
 revision = '3be65537a94a'
 down_revision = '4e263f236334'
 
-from alembic import op
-import sqlalchemy as sa
+from alembic import op  # noqa: E402
+
+from oslo_db.sqlalchemy.types import String  # noqa: E402
+
+import sqlalchemy as sa  # noqa: E402
+
+from sqlalchemy.dialects.mysql import TINYTEXT  # noqa: E402
 
 
 def upgrade():
     op.add_column('baymodel', sa.Column('network_driver',
-                  sa.String(length=255), nullable=True))
+                  String(255, mysql_ndb_type=TINYTEXT), nullable=True))
